@@ -9,11 +9,11 @@ App::PM::Announce - Announce your PM meeting via Meetup and LinkedIn
 
 =head1 VERSION
 
-Version 0.022
+Version 0.023
 
 =cut
 
-our $VERSION = '0.022';
+our $VERSION = '0.023';
 
 use Moose;
 #with 'MooseX::LogDispatch';
@@ -34,6 +34,7 @@ use App::PM::Announce::History;
 use App::PM::Announce::Feed::meetup;
 use App::PM::Announce::Feed::linkedin;
 use App::PM::Announce::Feed::greymatter;
+use App::PM::Announce::Feed::useperl;
 
 sub BUILD {
     my $self = shift;
@@ -121,6 +122,7 @@ sub _build_feed {
         meetup => $self->_build_meetup_feed,
         linkedin => $self->_build_linkedin_feed,
         greymatter => $self->_build_greymatter_feed,
+        useperl => $self->_build_useperl_feed,
     };
 }
 
@@ -136,6 +138,17 @@ sub _build_meetup_feed {
     );
 }
 
+sub _build_linkedin_feed {
+    my $self = shift;
+    return undef unless my $given = $self->config->{feed}->{linkedin};
+    return App::PM::Announce::Feed::linkedin->new(
+        app => $self,
+        username => $given->{username},
+        password => $given->{password},
+        uri => $given->{uri},
+    );
+}
+
 sub _build_greymatter_feed {
     my $self = shift;
     return undef unless my $given = $self->config->{feed}->{greymatter};
@@ -147,14 +160,14 @@ sub _build_greymatter_feed {
     );
 }
 
-sub _build_linkedin_feed {
+sub _build_useperl_feed {
     my $self = shift;
-    return undef unless my $given = $self->config->{feed}->{linkedin};
-    return App::PM::Announce::Feed::linkedin->new(
+    return undef unless my $given = $self->config->{feed}->{useperl};
+    return App::PM::Announce::Feed::useperl->new(
         app => $self,
         username => $given->{username},
         password => $given->{password},
-        uri => $given->{uri},
+        promote => $given->{promote},
     );
 }
 
@@ -219,6 +232,11 @@ sub startup {
 #    uri http://example.com/cgi-bin/greymatter/gm.cgi
 #</feed>
 
+#<feed useperl>
+#    username
+#    password
+#</feed>
+
 _END_
     }
 }
@@ -335,6 +353,31 @@ sub announce {
         else {
             $self->logger->debug( "No feed configured for greymatter" );
         }
+
+        if ($event->{did_useperl}) {
+            $self->logger->debug( "Already posted to useperl, skipping" );
+            push @report, "Already announced on useperl";
+        }
+        elsif ($self->feed->{useperl}) {
+            unless ($self->dry_run) {
+                die "Didn't announce on useperl" unless $result = $self->feed->{useperl}->announce(
+                    %event,
+                    description => [
+                        $event{description},
+                        "\nRSVP at Meetup - <a href=\"$event->{meetup_link}\">$event->{meetup_link}</a>"
+                    ],
+                );
+                $self->logger->info( "\"$event{title}\" ($uuid) announced to useperl" );
+                $result = $self->history->update( $uuid => did_useperl => 1 );
+                push @report, "Announced on useperl";
+            }
+            else {
+                push @report, "Would announce on useperl";
+            }
+        }
+        else {
+            $self->logger->debug( "No feed configured for useperl" );
+        }
     };
     if ($@) {
         warn "Unable to announce \"$event{title}\" ($uuid)\n";
@@ -367,6 +410,7 @@ sub parse {
 
 sub template {
     my $self = shift;
+    my %given = @_;
 
     my $uuid = Data::UUID->new->create_str;
     my $datetime = DateTimeX::Easy->parse( '4th tuesday' );
@@ -382,6 +426,7 @@ sub template {
 title: The title of the event
 venue: $venue
 datetime: $datetime
+image: $given{image}
 uuid: $uuid
 ---
 Put your multi-line description for the event here.
@@ -406,29 +451,28 @@ _END_
 
 App::PM::Announce is a tool for creating and advertising PM meetings (on Meetup, LinkedIn, and blog software)
 
-    OPTIONS
-
-        -v, -d,  --verbose   Debugging mode. Be verbose when reporting
-        -h, -?,  --help      This help screen
-        -n,      --dry-run   Don't actually login and announce, just show what would be done
-
-    COMMANDS
+            -v, -d,  --verbose  Debugging mode. Be verbose when reporting
+            -h, -?,  --help     This help screen
 
         config              Check the config file ($HOME/.app-pm-announce/config)
 
-        config edit         Edit the config file using $EDITOR
+        config edit             Edit the config file using $EDITOR
 
-        history             Show announcement history
+        history                 Show announcement history
 
-        history <query>     Show announcement history for event <query>, where <query> should be enough of the uuid to be unambiguous
+        history <query>         Show announcement history for event <query>, where <query> should be enough of the uuid to be unambiguous
 
-        template            Print out a template to be used for input to the 'announce' command
+        template                Print out a template to be used for input to the 'announce' command
 
-        announce            Read STDIN for the event information and make a post for each feed
+            --image <image>     Attach <image> (can be either a local file or remote URL) to the Meetup event
 
-        test                Post a bogus event to a test meetup account, test linkedin account, and test greymatter account
+        announce                Read STDIN for the event information and make a post for each feed
 
-        help                This help screen
+            -n, --dry-run       Don't actually login and announce, just show what would be done
+
+        test                    Post a bogus event to a test meetup account, test linkedin account, and test greymatter account
+
+        help                    This help screen
 
 =cut
 
